TensorFlow graph construction
=============================

The TensorGraph class manages all the data and build processes associated with
the TensorFlow graph.  The TensorFlow graph is the symbolic description of
the computations in the network, which will be executed by the simulator.

.. automodule:: nengo_dl.tensor_graph